==> aws-sdk-cpp-1.7.271-1-aarch64.pkg.tar.xz: usr/include/aws/iotevents/model/Action.h <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#pragma once
#include <aws/iotevents/IoTEvents_EXPORTS.h>
#include <aws/iotevents/model/SetVariableAction.h>
#include <aws/iotevents/model/SNSTopicPublishAction.h>
#include <aws/iotevents/model/IotTopicPublishAction.h>
#include <aws/iotevents/model/SetTimerAction.h>
#include <aws/iotevents/model/ClearTimerAction.h>
#include <aws/iotevents/model/ResetTimerAction.h>
#include <aws/iotevents/model/LambdaAction.h>
#include <aws/iotevents/model/IotEventsAction.h>
#include <aws/iotevents/model/SqsAction.h>
#include <aws/iotevents/model/FirehoseAction.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace IoTEvents
{
namespace Model
{

  /**
   * <p>An action to be performed when the <code>"condition"</code> is
   * TRUE.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/iotevents-2018-07-27/Action">AWS
   * API Reference</a></p>
   */
  class AWS_IOTEVENTS_API Action
  {
  public:
    Action();
    Action(Aws::Utils::Json::JsonView jsonValue);
    Action& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline const SetVariableAction& GetSetVariable() const{ return m_setVariable; }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline bool SetVariableHasBeenSet() const { return m_setVariableHasBeenSet; }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline void SetSetVariable(const SetVariableAction& value) { m_setVariableHasBeenSet = true; m_setVariable = value; }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline void SetSetVariable(SetVariableAction&& value) { m_setVariableHasBeenSet = true; m_setVariable = std::move(value); }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline Action& WithSetVariable(const SetVariableAction& value) { SetSetVariable(value); return *this;}

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline Action& WithSetVariable(SetVariableAction&& value) { SetSetVariable(std::move(value)); return *this;}


    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline const SNSTopicPublishAction& GetSns() const{ return m_sns; }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline bool SnsHasBeenSet() const { return m_snsHasBeenSet; }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline void SetSns(const SNSTopicPublishAction& value) { m_snsHasBeenSet = true; m_sns = value; }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline void SetSns(SNSTopicPublishAction&& value) { m_snsHasBeenSet = true; m_sns = std::move(value); }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline Action& WithSns(const SNSTopicPublishAction& value) { SetSns(value); return *this;}

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline Action& WithSns(SNSTopicPublishAction&& value) { SetSns(std::move(value)); return *this;}


    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline const IotTopicPublishAction& GetIotTopicPublish() const{ return m_iotTopicPublish; }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline bool IotTopicPublishHasBeenSet() const { return m_iotTopicPublishHasBeenSet; }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline void SetIotTopicPublish(const IotTopicPublishAction& value) { m_iotTopicPublishHasBeenSet = true; m_iotTopicPublish = value; }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline void SetIotTopicPublish(IotTopicPublishAction&& value) { m_iotTopicPublishHasBeenSet = true; m_iotTopicPublish = std::move(value); }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline Action& WithIotTopicPublish(const IotTopicPublishAction& value) { SetIotTopicPublish(value); return *this;}

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline Action& WithIotTopicPublish(IotTopicPublishAction&& value) { SetIotTopicPublish(std::move(value)); return *this;}


    /**
     * <p>Information needed to set the timer.</p>
     */
    inline const SetTimerAction& GetSetTimer() const{ return m_setTimer; }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline bool SetTimerHasBeenSet() const { return m_setTimerHasBeenSet; }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline void SetSetTimer(const SetTimerAction& value) { m_setTimerHasBeenSet = true; m_setTimer = value; }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline void SetSetTimer(SetTimerAction&& value) { m_setTimerHasBeenSet = true; m_setTimer = std::move(value); }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline Action& WithSetTimer(const SetTimerAction& value) { SetSetTimer(value); return *this;}

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline Action& WithSetTimer(SetTimerAction&& value) { SetSetTimer(std::move(value)); return *this;}


    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline const ClearTimerAction& GetClearTimer() const{ return m_clearTimer; }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline bool ClearTimerHasBeenSet() const { return m_clearTimerHasBeenSet; }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline void SetClearTimer(const ClearTimerAction& value) { m_clearTimerHasBeenSet = true; m_clearTimer = value; }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline void SetClearTimer(ClearTimerAction&& value) { m_clearTimerHasBeenSet = true; m_clearTimer = std::move(value); }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline Action& WithClearTimer(const ClearTimerAction& value) { SetClearTimer(value); return *this;}

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline Action& WithClearTimer(ClearTimerAction&& value) { SetClearTimer(std::move(value)); return *this;}


    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline const ResetTimerAction& GetResetTimer() const{ return m_resetTimer; }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline bool ResetTimerHasBeenSet() const { return m_resetTimerHasBeenSet; }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline void SetResetTimer(const ResetTimerAction& value) { m_resetTimerHasBeenSet = true; m_resetTimer = value; }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline void SetResetTimer(ResetTimerAction&& value) { m_resetTimerHasBeenSet = true; m_resetTimer = std::move(value); }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline Action& WithResetTimer(const ResetTimerAction& value) { SetResetTimer(value); return *this;}

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline Action& WithResetTimer(ResetTimerAction&& value) { SetResetTimer(std::move(value)); return *this;}


    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline const LambdaAction& GetLambda() const{ return m_lambda; }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline bool LambdaHasBeenSet() const { return m_lambdaHasBeenSet; }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline void SetLambda(const LambdaAction& value) { m_lambdaHasBeenSet = true; m_lambda = value; }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline void SetLambda(LambdaAction&& value) { m_lambdaHasBeenSet = true; m_lambda = std::move(value); }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline Action& WithLambda(const LambdaAction& value) { SetLambda(value); return *this;}

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline Action& WithLambda(LambdaAction&& value) { SetLambda(std::move(value)); return *this;}


    /**
     * <p>Sends an IoT Events input, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline const IotEventsAction& GetIotEvents() const{ return m_iotEvents; }

    /**
     * <p>Sends an IoT Events input, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline bool IotEventsHasBeenSet() const { return m_iotEventsHasBeenSet; }

    /**
     * <p>Sends an IoT Events input, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline void SetIotEvents(const IotEventsAction& value) { m_iotEventsHasBeenSet = true; m_iotEvents = value; }

    /**
     * <p>Sends an IoT Events input, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline void SetIotEvents(IotEventsAction&& value) { m_iotEventsHasBeenSet = true; m_iotEvents = std::move(value); }

    /**
     * <p>Sends an IoT Events input, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline Action& WithIotEvents(const IotEventsAction& value) { SetIotEvents(value); return *this;}

    /**
     * <p>Sends an IoT Events input, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline Action& WithIotEvents(IotEventsAction&& value) { SetIotEvents(std::move(value)); return *this;}


    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline const SqsAction& GetSqs() const{ return m_sqs; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline bool SqsHasBeenSet() const { return m_sqsHasBeenSet; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline void SetSqs(const SqsAction& value) { m_sqsHasBeenSet = true; m_sqs = value; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline void SetSqs(SqsAction&& value) { m_sqsHasBeenSet = true; m_sqs = std::move(value); }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline Action& WithSqs(const SqsAction& value) { SetSqs(value); return *this;}

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline Action& WithSqs(SqsAction&& value) { SetSqs(std::move(value)); return *this;}


    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to a Kinesis Data Firehose delivery stream.</p>
     */
    inline const FirehoseAction& GetFirehose() const{ return m_firehose; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to a Kinesis Data Firehose delivery stream.</p>
     */
    inline bool FirehoseHasBeenSet() const { return m_firehoseHasBeenSet; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to a Kinesis Data Firehose delivery stream.</p>
     */
    inline void SetFirehose(const FirehoseAction& value) { m_firehoseHasBeenSet = true; m_firehose = value; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to a Kinesis Data Firehose delivery stream.</p>
     */
    inline void SetFirehose(FirehoseAction&& value) { m_firehoseHasBeenSet = true; m_firehose = std::move(value); }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to a Kinesis Data Firehose delivery stream.</p>
     */
    inline Action& WithFirehose(const FirehoseAction& value) { SetFirehose(value); return *this;}

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to a Kinesis Data Firehose delivery stream.</p>
     */
    inline Action& WithFirehose(FirehoseAction&& value) { SetFirehose(std::move(value)); return *this;}

  private:

    SetVariableAction m_setVariable;
    bool m_setVariableHasBeenSet;

    SNSTopicPublishAction m_sns;
    bool m_snsHasBeenSet;

    IotTopicPublishAction m_iotTopicPublish;
    bool m_iotTopicPublishHasBeenSet;

    SetTimerAction m_setTimer;
    bool m_setTimerHasBeenSet;

    ClearTimerAction m_clearTimer;
    bool m_clearTimerHasBeenSet;

    ResetTimerAction m_resetTimer;
    bool m_resetTimerHasBeenSet;

    LambdaAction m_lambda;
    bool m_lambdaHasBeenSet;

    IotEventsAction m_iotEvents;
    bool m_iotEventsHasBeenSet;

    SqsAction m_sqs;
    bool m_sqsHasBeenSet;

    FirehoseAction m_firehose;
    bool m_firehoseHasBeenSet;
  };

} // namespace Model
} // namespace IoTEvents
} // namespace Aws

==> aws-sdk-cpp-1.7.306-1-aarch64.pkg.tar.xz: usr/include/aws/iotevents/model/Action.h <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#pragma once
#include <aws/iotevents/IoTEvents_EXPORTS.h>
#include <aws/iotevents/model/SetVariableAction.h>
#include <aws/iotevents/model/SNSTopicPublishAction.h>
#include <aws/iotevents/model/IotTopicPublishAction.h>
#include <aws/iotevents/model/SetTimerAction.h>
#include <aws/iotevents/model/ClearTimerAction.h>
#include <aws/iotevents/model/ResetTimerAction.h>
#include <aws/iotevents/model/LambdaAction.h>
#include <aws/iotevents/model/IotEventsAction.h>
#include <aws/iotevents/model/SqsAction.h>
#include <aws/iotevents/model/FirehoseAction.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace IoTEvents
{
namespace Model
{

  /**
   * <p>An action to be performed when the <code>condition</code> is
   * TRUE.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/iotevents-2018-07-27/Action">AWS
   * API Reference</a></p>
   */
  class AWS_IOTEVENTS_API Action
  {
  public:
    Action();
    Action(Aws::Utils::Json::JsonView jsonValue);
    Action& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline const SetVariableAction& GetSetVariable() const{ return m_setVariable; }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline bool SetVariableHasBeenSet() const { return m_setVariableHasBeenSet; }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline void SetSetVariable(const SetVariableAction& value) { m_setVariableHasBeenSet = true; m_setVariable = value; }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline void SetSetVariable(SetVariableAction&& value) { m_setVariableHasBeenSet = true; m_setVariable = std::move(value); }

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline Action& WithSetVariable(const SetVariableAction& value) { SetSetVariable(value); return *this;}

    /**
     * <p>Sets a variable to a specified value.</p>
     */
    inline Action& WithSetVariable(SetVariableAction&& value) { SetSetVariable(std::move(value)); return *this;}


    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline const SNSTopicPublishAction& GetSns() const{ return m_sns; }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline bool SnsHasBeenSet() const { return m_snsHasBeenSet; }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline void SetSns(const SNSTopicPublishAction& value) { m_snsHasBeenSet = true; m_sns = value; }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline void SetSns(SNSTopicPublishAction&& value) { m_snsHasBeenSet = true; m_sns = std::move(value); }

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline Action& WithSns(const SNSTopicPublishAction& value) { SetSns(value); return *this;}

    /**
     * <p>Sends an Amazon SNS message.</p>
     */
    inline Action& WithSns(SNSTopicPublishAction&& value) { SetSns(std::move(value)); return *this;}


    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline const IotTopicPublishAction& GetIotTopicPublish() const{ return m_iotTopicPublish; }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline bool IotTopicPublishHasBeenSet() const { return m_iotTopicPublishHasBeenSet; }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline void SetIotTopicPublish(const IotTopicPublishAction& value) { m_iotTopicPublishHasBeenSet = true; m_iotTopicPublish = value; }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline void SetIotTopicPublish(IotTopicPublishAction&& value) { m_iotTopicPublishHasBeenSet = true; m_iotTopicPublish = std::move(value); }

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline Action& WithIotTopicPublish(const IotTopicPublishAction& value) { SetIotTopicPublish(value); return *this;}

    /**
     * <p>Publishes an MQTT message with the given topic to the AWS IoT message
     * broker.</p>
     */
    inline Action& WithIotTopicPublish(IotTopicPublishAction&& value) { SetIotTopicPublish(std::move(value)); return *this;}


    /**
     * <p>Information needed to set the timer.</p>
     */
    inline const SetTimerAction& GetSetTimer() const{ return m_setTimer; }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline bool SetTimerHasBeenSet() const { return m_setTimerHasBeenSet; }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline void SetSetTimer(const SetTimerAction& value) { m_setTimerHasBeenSet = true; m_setTimer = value; }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline void SetSetTimer(SetTimerAction&& value) { m_setTimerHasBeenSet = true; m_setTimer = std::move(value); }

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline Action& WithSetTimer(const SetTimerAction& value) { SetSetTimer(value); return *this;}

    /**
     * <p>Information needed to set the timer.</p>
     */
    inline Action& WithSetTimer(SetTimerAction&& value) { SetSetTimer(std::move(value)); return *this;}


    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline const ClearTimerAction& GetClearTimer() const{ return m_clearTimer; }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline bool ClearTimerHasBeenSet() const { return m_clearTimerHasBeenSet; }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline void SetClearTimer(const ClearTimerAction& value) { m_clearTimerHasBeenSet = true; m_clearTimer = value; }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline void SetClearTimer(ClearTimerAction&& value) { m_clearTimerHasBeenSet = true; m_clearTimer = std::move(value); }

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline Action& WithClearTimer(const ClearTimerAction& value) { SetClearTimer(value); return *this;}

    /**
     * <p>Information needed to clear the timer.</p>
     */
    inline Action& WithClearTimer(ClearTimerAction&& value) { SetClearTimer(std::move(value)); return *this;}


    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline const ResetTimerAction& GetResetTimer() const{ return m_resetTimer; }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline bool ResetTimerHasBeenSet() const { return m_resetTimerHasBeenSet; }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline void SetResetTimer(const ResetTimerAction& value) { m_resetTimerHasBeenSet = true; m_resetTimer = value; }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline void SetResetTimer(ResetTimerAction&& value) { m_resetTimerHasBeenSet = true; m_resetTimer = std::move(value); }

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline Action& WithResetTimer(const ResetTimerAction& value) { SetResetTimer(value); return *this;}

    /**
     * <p>Information needed to reset the timer.</p>
     */
    inline Action& WithResetTimer(ResetTimerAction&& value) { SetResetTimer(std::move(value)); return *this;}


    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline const LambdaAction& GetLambda() const{ return m_lambda; }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline bool LambdaHasBeenSet() const { return m_lambdaHasBeenSet; }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline void SetLambda(const LambdaAction& value) { m_lambdaHasBeenSet = true; m_lambda = value; }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline void SetLambda(LambdaAction&& value) { m_lambdaHasBeenSet = true; m_lambda = std::move(value); }

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline Action& WithLambda(const LambdaAction& value) { SetLambda(value); return *this;}

    /**
     * <p>Calls a Lambda function, passing in information about the detector model
     * instance and the event that triggered the action.</p>
     */
    inline Action& WithLambda(LambdaAction&& value) { SetLambda(std::move(value)); return *this;}


    /**
     * <p>Sends an AWS IoT Events input, passing in information about the detector
     * model instance and the event that triggered the action.</p>
     */
    inline const IotEventsAction& GetIotEvents() const{ return m_iotEvents; }

    /**
     * <p>Sends an AWS IoT Events input, passing in information about the detector
     * model instance and the event that triggered the action.</p>
     */
    inline bool IotEventsHasBeenSet() const { return m_iotEventsHasBeenSet; }

    /**
     * <p>Sends an AWS IoT Events input, passing in information about the detector
     * model instance and the event that triggered the action.</p>
     */
    inline void SetIotEvents(const IotEventsAction& value) { m_iotEventsHasBeenSet = true; m_iotEvents = value; }

    /**
     * <p>Sends an AWS IoT Events input, passing in information about the detector
     * model instance and the event that triggered the action.</p>
     */
    inline void SetIotEvents(IotEventsAction&& value) { m_iotEventsHasBeenSet = true; m_iotEvents = std::move(value); }

    /**
     * <p>Sends an AWS IoT Events input, passing in information about the detector
     * model instance and the event that triggered the action.</p>
     */
    inline Action& WithIotEvents(const IotEventsAction& value) { SetIotEvents(value); return *this;}

    /**
     * <p>Sends an AWS IoT Events input, passing in information about the detector
     * model instance and the event that triggered the action.</p>
     */
    inline Action& WithIotEvents(IotEventsAction&& value) { SetIotEvents(std::move(value)); return *this;}


    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline const SqsAction& GetSqs() const{ return m_sqs; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline bool SqsHasBeenSet() const { return m_sqsHasBeenSet; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline void SetSqs(const SqsAction& value) { m_sqsHasBeenSet = true; m_sqs = value; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline void SetSqs(SqsAction&& value) { m_sqsHasBeenSet = true; m_sqs = std::move(value); }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline Action& WithSqs(const SqsAction& value) { SetSqs(value); return *this;}

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon SQS queue.</p>
     */
    inline Action& WithSqs(SqsAction&& value) { SetSqs(std::move(value)); return *this;}


    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon Kinesis Data Firehose delivery stream.</p>
     */
    inline const FirehoseAction& GetFirehose() const{ return m_firehose; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon Kinesis Data Firehose delivery stream.</p>
     */
    inline bool FirehoseHasBeenSet() const { return m_firehoseHasBeenSet; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon Kinesis Data Firehose delivery stream.</p>
     */
    inline void SetFirehose(const FirehoseAction& value) { m_firehoseHasBeenSet = true; m_firehose = value; }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon Kinesis Data Firehose delivery stream.</p>
     */
    inline void SetFirehose(FirehoseAction&& value) { m_firehoseHasBeenSet = true; m_firehose = std::move(value); }

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon Kinesis Data Firehose delivery stream.</p>
     */
    inline Action& WithFirehose(const FirehoseAction& value) { SetFirehose(value); return *this;}

    /**
     * <p>Sends information about the detector model instance and the event that
     * triggered the action to an Amazon Kinesis Data Firehose delivery stream.</p>
     */
    inline Action& WithFirehose(FirehoseAction&& value) { SetFirehose(std::move(value)); return *this;}

  private:

    SetVariableAction m_setVariable;
    bool m_setVariableHasBeenSet;

    SNSTopicPublishAction m_sns;
    bool m_snsHasBeenSet;

    IotTopicPublishAction m_iotTopicPublish;
    bool m_iotTopicPublishHasBeenSet;

    SetTimerAction m_setTimer;
    bool m_setTimerHasBeenSet;

    ClearTimerAction m_clearTimer;
    bool m_clearTimerHasBeenSet;

    ResetTimerAction m_resetTimer;
    bool m_resetTimerHasBeenSet;

    LambdaAction m_lambda;
    bool m_lambdaHasBeenSet;

    IotEventsAction m_iotEvents;
    bool m_iotEventsHasBeenSet;

    SqsAction m_sqs;
    bool m_sqsHasBeenSet;

    FirehoseAction m_firehose;
    bool m_firehoseHasBeenSet;
  };

} // namespace Model
} // namespace IoTEvents
} // namespace Aws
